ます’s Blog - どうでもいい記事100選

どうでもいい記事100選

error: redefinition of typedef 'STATUS'

未だにstaticにビルドしようとしている自分もアレなんですが。
三者(自分・pecl_http・FreeTDS)含めて、どっちもどっち、という感じか。_| ̄|○

% cd /usr/local/src/php-4.4.8
% make
gcc  -Imain/ -I/usr/local/src/wk/php-4.4.8/main/ -DPHP_ATOM_INC -I/usr/local/src/wk/php-4.4.8/include -I/usr/local/src/wk/php-4.4.8/main -I/usr/local/src/wk/php-4.4.8 -I/usr/local/freetds/include -I/usr/local/mysql/include/mysql -I/usr/local/src/wk/php-4.4.8/ext/xml/expat -I/usr/local/src/wk/php-4.4.8/TSRM -I/usr/local/src/wk/php-4.4.8/Zend    -g -O2  -c main/internal_functions.c -o main/internal_functions.o  && echo > main/internal_functions.lo
In file included from /usr/local/src/wk/php-4.4.8/ext/http/php_http.h:30,
                 from main/internal_functions.c:42:
/usr/local/src/wk/php-4.4.8/ext/http/php_http_std_defs.h:31: error: redefinition of typedef 'STATUS'
/usr/local/freetds/include/sybdb.h:139: error: previous declaration of 'STATUS' was here
make: *** [main/internal_functions.lo] Error 1
% cd ../php-5.2.5
% make
/bin/sh /usr/local/src/wk/php-5.2.5/libtool --silent --preserve-dup-deps --mode=compile gcc  -Imain/ -I/usr/local/src/wk/php-5.2.5/main/ -DPHP_ATOM_INC -I/usr/local/src/wk/php-5.2.5/include -I/usr/local/src/wk/php-5.2.5/main -I/usr/local/src/wk/php-5.2.5 -I/usr/include/libxml2 -I/usr/local/src/wk/php-5.2.5/ext/date/lib -I/usr/local/freetds/include -I/usr/local/mysql/include/mysql -I/usr/local/src/wk/php-5.2.5/ext/hash -I/usr/local/src/wk/php-5.2.5/TSRM -I/usr/local/src/wk/php-5.2.5/Zend    -I/usr/local/include -g -O2  -c main/internal_functions.c -o main/internal_functions.lo
In file included from /usr/local/src/wk/php-5.2.5/ext/http/php_http.h:30,
                 from main/internal_functions.c:55:
/usr/local/src/wk/php-5.2.5/ext/http/php_http_std_defs.h:31: error: redefinition of typedef 'STATUS'
/usr/local/freetds/include/sybdb.h:139: error: previous declaration of 'STATUS' was here
make: *** [main/internal_functions.lo] Error 1

誰もが連想しそうなキーワードを使っているのは微妙。
ただ、ここで諦める訳にはいかない?ので、勢いに任せて適当に逃げ。パッチがデカすぎ。

diff -urN pecl_http-1.6.0,orig/http.c pecl_http-1.6.0/http.c
--- pecl_http-1.6.0,orig/http.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http.c	2008-01-24 11:46:20.000000000 +0900
@@ -385,7 +385,7 @@
 /* {{{ PHP_RSHUTDOWN_FUNCTION */
 PHP_RSHUTDOWN_FUNCTION(http)
 {
-	STATUS status = SUCCESS;
+	PECL_HTTP_STATUS status = SUCCESS;
 	
 	if (0
 #ifdef HTTP_HAVE_ZLIB
diff -urN pecl_http-1.6.0,orig/http_cache_api.c pecl_http-1.6.0/http_cache_api.c
--- pecl_http-1.6.0,orig/http_cache_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_cache_api.c	2008-01-24 11:46:20.000000000 +0900
@@ -31,7 +31,7 @@
 	if (data_mode == SEND_DATA) {
 		http_etag_update(ctx, data_ptr, data_len);
 	} else {
-		STATUS ss = FAILURE;
+		PECL_HTTP_STATUS ss = FAILURE;
 		php_stream_statbuf ssb;
 		
 		if (data_mode == SEND_RSRC) {
@@ -120,8 +120,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_cache_last_modified(time_t, time_t, char *, size_t) */
-PHP_HTTP_API STATUS _http_cache_last_modified(time_t last_modified,
+/* {{{ PECL_HTTP_STATUS http_cache_last_modified(time_t, time_t, char *, size_t) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_cache_last_modified(time_t last_modified,
 	time_t send_modified, const char *cache_control, size_t cc_len TSRMLS_DC)
 {
 	char *sent_header = NULL;
@@ -148,8 +148,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_cache_etag(char *, size_t, char *, size_t) */
-PHP_HTTP_API STATUS _http_cache_etag(const char *etag, size_t etag_len,
+/* {{{ PECL_HTTP_STATUS http_cache_etag(char *, size_t, char *, size_t) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_cache_etag(const char *etag, size_t etag_len,
 	const char *cache_control, size_t cc_len TSRMLS_DC)
 {
 	char *sent_header = NULL;
@@ -179,7 +179,7 @@
 }
 /* }}} */
 
-PHP_HTTP_API STATUS _http_start_ob_etaghandler(TSRMLS_D)
+PHP_HTTP_API PECL_HTTP_STATUS _http_start_ob_etaghandler(TSRMLS_D)
 {
 	/* already running? */
 	if (php_ob_handler_used("ob_etaghandler" TSRMLS_CC)) {
diff -urN pecl_http-1.6.0,orig/http_encoding_api.c pecl_http-1.6.0/http_encoding_api.c
--- pecl_http-1.6.0,orig/http_encoding_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_encoding_api.c	2008-01-24 11:46:21.000000000 +0900
@@ -181,7 +181,7 @@
 		add_next_index_stringl(&zsupported, "deflate", lenof("deflate"), 1);
 		
 		if ((selected = http_negotiate_encoding(&zsupported))) {
-			STATUS hs = FAILURE;
+			PECL_HTTP_STATUS hs = FAILURE;
 			char *encoding = NULL;
 			ulong idx;
 			
@@ -269,8 +269,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_deflate(int, char *, size_t, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_deflate(int flags, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_deflate(int, char *, size_t, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate(int flags, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	int status, level, wbits, strategy;
 	z_stream Z;
@@ -312,8 +312,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_inflate(char *, size_t, char **, size_t) */
-PHP_HTTP_API STATUS _http_encoding_inflate(const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_inflate(char *, size_t, char **, size_t) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate(const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	z_stream Z;
 	int status, wbits = HTTP_WINDOW_BITS_ANY;
@@ -412,8 +412,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_deflate_stream_update(http_encoding_stream *, char *, size_t, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_deflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_deflate_stream_update(http_encoding_stream *, char *, size_t, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	int status;
 	
@@ -453,8 +453,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_inflate_stream_update(http_encoding_stream *, char *, size_t, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_inflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_inflate_stream_update(http_encoding_stream *, char *, size_t, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	int status;
 	
@@ -491,8 +491,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_deflate_stream_flush(http_encoding_stream *, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_deflate_stream_flush(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_deflate_stream_flush(http_encoding_stream *, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate_stream_flush(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	int status;
 	
@@ -520,8 +520,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_inflate_straem_flush(http_encoding_stream *, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_inflate_stream_flush(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_inflate_straem_flush(http_encoding_stream *, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate_stream_flush(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	/* noop */
 	*decoded = estrndup("", *decoded_len = 0);
@@ -529,8 +529,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_deflate_stream_finish(http_encoding_stream *, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_deflate_stream_finish(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_deflate_stream_finish(http_encoding_stream *, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate_stream_finish(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	int status;
 	
@@ -566,8 +566,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_encoding_inflate_stream_finish(http_encoding_stream *, char **, size_t *) */
-PHP_HTTP_API STATUS _http_encoding_inflate_stream_finish(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_encoding_inflate_stream_finish(http_encoding_stream *, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate_stream_finish(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC)
 {
 	int status;
 	
diff -urN pecl_http-1.6.0,orig/http_headers_api.c pecl_http-1.6.0/http_headers_api.c
--- pecl_http-1.6.0,orig/http_headers_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_headers_api.c	2008-01-24 11:46:22.000000000 +0900
@@ -332,8 +332,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_parse_headers(char *, HashTable *, zend_bool) */
-PHP_HTTP_API STATUS _http_parse_headers_ex(const char *header, HashTable *headers, zend_bool prettify, 
+/* {{{ PECL_HTTP_STATUS http_parse_headers(char *, HashTable *, zend_bool) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_parse_headers_ex(const char *header, HashTable *headers, zend_bool prettify, 
 	http_info_callback callback_func, void **callback_data TSRMLS_DC)
 {
 	const char *colon = NULL, *line = NULL;
@@ -473,10 +473,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_get_response_headers(HashTable *) */
-PHP_HTTP_API STATUS _http_get_response_headers(HashTable *headers_ht TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_get_response_headers(HashTable *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_get_response_headers(HashTable *headers_ht TSRMLS_DC)
 {
-	STATUS status;
+	PECL_HTTP_STATUS status;
 	phpstr headers;
 	
 	phpstr_init(&headers);
diff -urN pecl_http-1.6.0,orig/http_info_api.c pecl_http-1.6.0/http_info_api.c
--- pecl_http-1.6.0,orig/http_info_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_info_api.c	2008-01-24 11:46:22.000000000 +0900
@@ -53,7 +53,7 @@
 	}
 }
 
-PHP_HTTP_API STATUS _http_info_parse_ex(const char *pre_header, http_info *info, zend_bool silent TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_info_parse_ex(const char *pre_header, http_info *info, zend_bool silent TSRMLS_DC)
 {
 	const char *end, *http;
 	
diff -urN pecl_http-1.6.0,orig/http_message_api.c pecl_http-1.6.0/http_message_api.c
--- pecl_http-1.6.0,orig/http_message_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_message_api.c	2008-01-24 11:46:23.000000000 +0900
@@ -546,9 +546,9 @@
 	}
 }
 
-PHP_HTTP_API STATUS _http_message_send(http_message *message TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_message_send(http_message *message TSRMLS_DC)
 {
-	STATUS rs = FAILURE;
+	PECL_HTTP_STATUS rs = FAILURE;
 
 	switch (message->type) {
 		case HTTP_MSG_RESPONSE:
diff -urN pecl_http-1.6.0,orig/http_persistent_handle_api.c pecl_http-1.6.0/http_persistent_handle_api.c
--- pecl_http-1.6.0,orig/http_persistent_handle_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_persistent_handle_api.c	2008-01-24 11:46:23.000000000 +0900
@@ -119,7 +119,7 @@
 	return NULL;
 }
 
-static inline STATUS http_persistent_handle_do_acquire(http_persistent_handle_provider *provider, void **handle TSRMLS_DC)
+static inline PECL_HTTP_STATUS http_persistent_handle_do_acquire(http_persistent_handle_provider *provider, void **handle TSRMLS_DC)
 {
 	ulong index;
 	void **handle_ptr;
@@ -146,7 +146,7 @@
 	return FAILURE;
 }
 
-static inline STATUS http_persistent_handle_do_release(http_persistent_handle_provider *provider, void **handle TSRMLS_DC)
+static inline PECL_HTTP_STATUS http_persistent_handle_do_release(http_persistent_handle_provider *provider, void **handle TSRMLS_DC)
 {
 	http_persistent_handle_list *list;
 	
@@ -168,7 +168,7 @@
 	return FAILURE;
 }
 
-static inline STATUS http_persistent_handle_do_accrete(http_persistent_handle_provider *provider, void *old_handle, void **new_handle TSRMLS_DC)
+static inline PECL_HTTP_STATUS http_persistent_handle_do_accrete(http_persistent_handle_provider *provider, void *old_handle, void **new_handle TSRMLS_DC)
 {
 	http_persistent_handle_list *list;
 	
@@ -215,9 +215,9 @@
 	return SUCCESS;
 }
 
-PHP_HTTP_API STATUS _http_persistent_handle_provide_ex(const char *name_str, size_t name_len, http_persistent_handle_ctor ctor, http_persistent_handle_dtor dtor, http_persistent_handle_copy copy)
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_provide_ex(const char *name_str, size_t name_len, http_persistent_handle_ctor ctor, http_persistent_handle_dtor dtor, http_persistent_handle_copy copy)
 {
-	STATUS status = FAILURE;
+	PECL_HTTP_STATUS status = FAILURE;
 	http_persistent_handle_provider provider;
 	
 	LOCK();
@@ -239,9 +239,9 @@
 	return status;
 }
 
-PHP_HTTP_API STATUS _http_persistent_handle_acquire_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_acquire_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC)
 {
-	STATUS status = FAILURE;
+	PECL_HTTP_STATUS status = FAILURE;
 	http_persistent_handle_provider *provider;
 	
 	*handle = NULL;
@@ -258,9 +258,9 @@
 	return status;
 }
 
-PHP_HTTP_API STATUS _http_persistent_handle_release_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_release_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC)
 {
-	STATUS status = FAILURE;
+	PECL_HTTP_STATUS status = FAILURE;
 	http_persistent_handle_provider *provider;
 #if HTTP_DEBUG_PHANDLES
 	void *handle_tmp = *handle;
@@ -279,9 +279,9 @@
 	return status;
 }
 
-PHP_HTTP_API STATUS _http_persistent_handle_accrete_ex(const char *name_str, size_t name_len, void *old_handle, void **new_handle TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_accrete_ex(const char *name_str, size_t name_len, void *old_handle, void **new_handle TSRMLS_DC)
 {
-	STATUS status = FAILURE;
+	PECL_HTTP_STATUS status = FAILURE;
 	http_persistent_handle_provider *provider;
 	
 	*new_handle = NULL;
diff -urN pecl_http-1.6.0,orig/http_querystring_object.c pecl_http-1.6.0/http_querystring_object.c
--- pecl_http-1.6.0,orig/http_querystring_object.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_querystring_object.c	2008-01-24 11:46:23.000000000 +0900
@@ -493,7 +493,7 @@
 	char *ie, *oe;
 	int ie_len, oe_len;
 	zval xa, *qa, *qs;
-	STATUS rs;
+	PECL_HTTP_STATUS rs;
 	
 	if (SUCCESS != zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ss", &ie, &ie_len, &oe, &oe_len)) {
 		RETURN_FALSE;
diff -urN pecl_http-1.6.0,orig/http_request_api.c pecl_http-1.6.0/http_request_api.c
--- pecl_http-1.6.0,orig/http_request_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_request_api.c	2008-01-24 11:46:24.000000000 +0900
@@ -374,8 +374,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_request_enable_cookies(http_request *) */
-PHP_HTTP_API STATUS _http_request_enable_cookies(http_request *request)
+/* {{{ PECL_HTTP_STATUS http_request_enable_cookies(http_request *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_enable_cookies(http_request *request)
 {
 	int initialized = 1;
 	TSRMLS_FETCH_FROM_CTX(request->tsrm_ls);
@@ -389,8 +389,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_request_reset_cookies(http_request *, int) */
-PHP_HTTP_API STATUS _http_request_reset_cookies(http_request *request, int session_only)
+/* {{{ PECL_HTTP_STATUS http_request_reset_cookies(http_request *, int) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_reset_cookies(http_request *request, int session_only)
 {
 	int initialized = 1;
 	TSRMLS_FETCH_FROM_CTX(request->tsrm_ls);
@@ -417,7 +417,7 @@
 }
 /* }}} */
 
-PHP_HTTP_API STATUS _http_request_flush_cookies(http_request *request)
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_flush_cookies(http_request *request)
 {
 	int initialized = 1;
 	TSRMLS_FETCH_FROM_CTX(request->tsrm_ls);
@@ -541,8 +541,8 @@
 	}
 }
 
-/* {{{ STATUS http_request_prepare(http_request *, HashTable *) */
-PHP_HTTP_API STATUS _http_request_prepare(http_request *request, HashTable *options)
+/* {{{ PECL_HTTP_STATUS http_request_prepare(http_request *, HashTable *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_prepare(http_request *request, HashTable *options)
 {
 	zval *zoption;
 	zend_bool range_req = 0;
diff -urN pecl_http-1.6.0,orig/http_request_body_api.c pecl_http-1.6.0/http_request_body_api.c
--- pecl_http-1.6.0,orig/http_request_body_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_request_body_api.c	2008-01-24 11:46:24.000000000 +0900
@@ -139,8 +139,8 @@
 	}
 }
 
-/* STATUS http_request_body_encode(http_request_body *, char**, size_t *) */
-PHP_HTTP_API STATUS _http_request_body_encode(http_request_body *body, char **buf, size_t *len TSRMLS_DC)
+/* PECL_HTTP_STATUS http_request_body_encode(http_request_body *, char**, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_body_encode(http_request_body *body, char **buf, size_t *len TSRMLS_DC)
 {
 	switch (body->type) {
 		case HTTP_REQUEST_BODY_CURLPOST:
diff -urN pecl_http-1.6.0,orig/http_request_datashare_api.c pecl_http-1.6.0/http_request_datashare_api.c
--- pecl_http-1.6.0,orig/http_request_datashare_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_request_datashare_api.c	2008-01-24 11:46:24.000000000 +0900
@@ -122,7 +122,7 @@
 	return share;
 }
 
-PHP_HTTP_API STATUS _http_request_datashare_attach(http_request_datashare *share, zval *request TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_datashare_attach(http_request_datashare *share, zval *request TSRMLS_DC)
 {
 	CURLcode rc;
 	getObjectEx(http_request_object, obj, request);
@@ -148,7 +148,7 @@
 	return SUCCESS;
 }
 
-PHP_HTTP_API STATUS _http_request_datashare_detach(http_request_datashare *share, zval *request TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_datashare_detach(http_request_datashare *share, zval *request TSRMLS_DC)
 {
 	CURLcode rc;
 	getObjectEx(http_request_object, obj, request);
@@ -197,7 +197,7 @@
 	*share = NULL;
 }
 
-PHP_HTTP_API STATUS _http_request_datashare_set(http_request_datashare *share, const char *option, size_t option_len, zend_bool enable TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_datashare_set(http_request_datashare *share, const char *option, size_t option_len, zend_bool enable TSRMLS_DC)
 {
 	curl_lock_data *opt;
 	CURLSHcode rc;
diff -urN pecl_http-1.6.0,orig/http_request_method_api.c pecl_http-1.6.0/http_request_method_api.c
--- pecl_http-1.6.0,orig/http_request_method_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_request_method_api.c	2008-01-24 11:46:24.000000000 +0900
@@ -201,7 +201,7 @@
 
 #define http_request_method_cncl(m, c) _http_request_method_cncl_ex((m), strlen(m), (c) TSRMLS_CC)
 #define http_request_method_cncl_ex(m, l, c) _http_request_method_cncl_ex((m), (l), (c) TSRMLS_CC)
-static STATUS _http_request_method_cncl_ex(const char *method_name, int method_name_len, char **cnst TSRMLS_DC)
+static PECL_HTTP_STATUS _http_request_method_cncl_ex(const char *method_name, int method_name_len, char **cnst TSRMLS_DC)
 {
 	int i;
 	char *cncl;
@@ -290,7 +290,7 @@
 	return method_num;
 }
 
-PHP_HTTP_API STATUS _http_request_method_unregister(int method TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_method_unregister(int method TSRMLS_DC)
 {
 	char **name;
 	
diff -urN pecl_http-1.6.0,orig/http_request_object.c pecl_http-1.6.0/http_request_object.c
--- pecl_http-1.6.0,orig/http_request_object.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_request_object.c	2008-01-24 11:46:25.000000000 +0900
@@ -546,9 +546,9 @@
 	}
 }
 
-STATUS _http_request_object_requesthandler(http_request_object *obj, zval *this_ptr TSRMLS_DC)
+PECL_HTTP_STATUS _http_request_object_requesthandler(http_request_object *obj, zval *this_ptr TSRMLS_DC)
 {
-	STATUS status = SUCCESS;
+	PECL_HTTP_STATUS status = SUCCESS;
 
 	http_request_reset(obj->request);
 	HTTP_CHECK_CURL_INIT(obj->request->ch, http_curl_init(obj->request), return FAILURE);
@@ -648,9 +648,9 @@
 	return status;
 }
 
-STATUS _http_request_object_responsehandler(http_request_object *obj, zval *this_ptr TSRMLS_DC)
+PECL_HTTP_STATUS _http_request_object_responsehandler(http_request_object *obj, zval *this_ptr TSRMLS_DC)
 {
-	STATUS ret;
+	PECL_HTTP_STATUS ret;
 	zval *info;
 	http_message *msg;
 	
diff -urN pecl_http-1.6.0,orig/http_request_pool_api.c pecl_http-1.6.0/http_request_pool_api.c
--- pecl_http-1.6.0,orig/http_request_pool_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_request_pool_api.c	2008-01-24 11:46:25.000000000 +0900
@@ -106,8 +106,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_request_pool_attach(http_request_pool *, zval *) */
-PHP_HTTP_API STATUS _http_request_pool_attach(http_request_pool *pool, zval *request)
+/* {{{ PECL_HTTP_STATUS http_request_pool_attach(http_request_pool *, zval *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_attach(http_request_pool *pool, zval *request)
 {
 	TSRMLS_FETCH_FROM_CTX(pool->tsrm_ls);
 	getObjectEx(http_request_object, req, request);
@@ -142,8 +142,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_request_pool_detach(http_request_pool *, zval *) */
-PHP_HTTP_API STATUS _http_request_pool_detach(http_request_pool *pool, zval *request)
+/* {{{ PECL_HTTP_STATUS http_request_pool_detach(http_request_pool *, zval *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_detach(http_request_pool *pool, zval *request)
 {
 	CURLMcode code;
 	TSRMLS_FETCH_FROM_CTX(pool->tsrm_ls);
@@ -249,8 +249,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_request_pool_send(http_request_pool *) */
-PHP_HTTP_API STATUS _http_request_pool_send(http_request_pool *pool)
+/* {{{ PECL_HTTP_STATUS http_request_pool_send(http_request_pool *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_send(http_request_pool *pool)
 {
 	TSRMLS_FETCH_FROM_CTX(pool->tsrm_ls);
 	
@@ -314,8 +314,8 @@
 #	define SELECT_ERROR -1
 #endif
 
-/* {{{ STATUS http_request_pool_select(http_request_pool *) */
-PHP_HTTP_API STATUS _http_request_pool_select(http_request_pool *pool)
+/* {{{ PECL_HTTP_STATUS http_request_pool_select(http_request_pool *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_select(http_request_pool *pool)
 {
 	int MAX;
 	fd_set R, W, E;
diff -urN pecl_http-1.6.0,orig/http_requestpool_object.c pecl_http-1.6.0/http_requestpool_object.c
--- pecl_http-1.6.0,orig/http_requestpool_object.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_requestpool_object.c	2008-01-24 11:46:25.000000000 +0900
@@ -207,7 +207,7 @@
 PHP_METHOD(HttpRequestPool, attach)
 {
 	zval *request;
-	STATUS status = FAILURE;
+	PECL_HTTP_STATUS status = FAILURE;
 	getObject(http_requestpool_object, obj);
 
 	SET_EH_THROW_HTTP();
@@ -228,7 +228,7 @@
 PHP_METHOD(HttpRequestPool, detach)
 {
 	zval *request;
-	STATUS status = FAILURE;
+	PECL_HTTP_STATUS status = FAILURE;
 	getObject(http_requestpool_object, obj);
 
 	SET_EH_THROW_HTTP();
@@ -245,7 +245,7 @@
 	Send all attached HttpRequest objects in parallel. */
 PHP_METHOD(HttpRequestPool, send)
 {
-	STATUS status;
+	PECL_HTTP_STATUS status;
 	getObject(http_requestpool_object, obj);
 
 	NO_ARGS;
diff -urN pecl_http-1.6.0,orig/http_send_api.c pecl_http-1.6.0/http_send_api.c
--- pecl_http-1.6.0,orig/http_send_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_send_api.c	2008-01-24 11:46:26.000000000 +0900
@@ -228,10 +228,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_header(char *, char *, zend_bool) */
-PHP_HTTP_API STATUS _http_send_header_ex(const char *name, size_t name_len, const char *value, size_t value_len, zend_bool replace, char **sent_header TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_header(char *, char *, zend_bool) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_header_ex(const char *name, size_t name_len, const char *value, size_t value_len, zend_bool replace, char **sent_header TSRMLS_DC)
 {
-	STATUS ret;
+	PECL_HTTP_STATUS ret;
 	
 	if (value && value_len) {
 		size_t header_len = sizeof(": ") + name_len + value_len + 1;
@@ -253,10 +253,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_status_header(int, char *) */
-PHP_HTTP_API STATUS _http_send_status_header_ex(int status, const char *header, size_t header_len, zend_bool replace TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_status_header(int, char *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_status_header_ex(int status, const char *header, size_t header_len, zend_bool replace TSRMLS_DC)
 {
-	STATUS ret;
+	PECL_HTTP_STATUS ret;
 	sapi_header_line h = {(char *) header, header_len, status};
 	if (SUCCESS != (ret = sapi_header_op(replace ? SAPI_HEADER_REPLACE : SAPI_HEADER_ADD, &h TSRMLS_CC))) {
 		http_error_ex(HE_WARNING, HTTP_E_HEADER, "Could not send header: %s (%d)", header, status);
@@ -265,10 +265,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_last_modified(int) */
-PHP_HTTP_API STATUS _http_send_last_modified_ex(time_t t, char **sent_header TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_last_modified(int) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_last_modified_ex(time_t t, char **sent_header TSRMLS_DC)
 {
-	STATUS ret;
+	PECL_HTTP_STATUS ret;
 	char *date = http_date(t);
 
 	if (!date) {
@@ -285,10 +285,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_etag(char *, size_t) */
-PHP_HTTP_API STATUS _http_send_etag_ex(const char *etag, size_t etag_len, char **sent_header TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_etag(char *, size_t) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_etag_ex(const char *etag, size_t etag_len, char **sent_header TSRMLS_DC)
 {
-	STATUS status;
+	PECL_HTTP_STATUS status;
 	char *etag_header;
 	size_t etag_header_len;
 
@@ -313,8 +313,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_content_type(char *, size_t) */
-PHP_HTTP_API STATUS _http_send_content_type(const char *content_type, size_t ct_len TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_content_type(char *, size_t) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_content_type(const char *content_type, size_t ct_len TSRMLS_DC)
 {
 	HTTP_CHECK_CONTENT_TYPE(content_type, return FAILURE);
 
@@ -326,10 +326,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_content_disposition(char *, size_t, zend_bool) */
-PHP_HTTP_API STATUS _http_send_content_disposition(const char *filename, size_t f_len, zend_bool send_inline TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_content_disposition(char *, size_t, zend_bool) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_content_disposition(const char *filename, size_t f_len, zend_bool send_inline TSRMLS_DC)
 {
-	STATUS status;
+	PECL_HTTP_STATUS status;
 	char *cd_header;
 
 	if (send_inline) {
@@ -346,8 +346,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send(void *, size_t, http_send_mode) */
-PHP_HTTP_API STATUS _http_send_ex(const void *data_ptr, size_t data_size, http_send_mode data_mode, zend_bool no_cache TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send(void *, size_t, http_send_mode) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_ex(const void *data_ptr, size_t data_size, http_send_mode data_mode, zend_bool no_cache TSRMLS_DC)
 {
 	void *s = NULL;
 	HashTable ranges;
@@ -501,10 +501,10 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_send_stream(php_stream *) */
-PHP_HTTP_API STATUS _http_send_stream_ex(php_stream *file, zend_bool close_stream, zend_bool no_cache TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_send_stream(php_stream *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_stream_ex(php_stream *file, zend_bool close_stream, zend_bool no_cache TSRMLS_DC)
 {
-	STATUS status;
+	PECL_HTTP_STATUS status;
 	php_stream_statbuf ssb;
 	int orig_flags;
 
diff -urN pecl_http-1.6.0,orig/http_url_api.c pecl_http-1.6.0/http_url_api.c
--- pecl_http-1.6.0,orig/http_url_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_url_api.c	2008-01-24 11:46:26.000000000 +0900
@@ -350,8 +350,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_urlencode_hash_ex(HashTable *, zend_bool, char *, size_t, char **, size_t *) */
-PHP_HTTP_API STATUS _http_urlencode_hash_ex(HashTable *hash, zend_bool override_argsep,
+/* {{{ PECL_HTTP_STATUS http_urlencode_hash_ex(HashTable *, zend_bool, char *, size_t, char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_urlencode_hash_ex(HashTable *hash, zend_bool override_argsep,
 	char *pre_encoded_data, size_t pre_encoded_len,
 	char **encoded_data, size_t *encoded_len TSRMLS_DC)
 {
@@ -381,7 +381,7 @@
 /* }}} */
 
 /* {{{ http_urlencode_hash_recursive */
-PHP_HTTP_API STATUS _http_urlencode_hash_recursive(HashTable *ht, phpstr *str, const char *arg_sep, size_t arg_sep_len, const char *prefix, size_t prefix_len TSRMLS_DC)
+PHP_HTTP_API PECL_HTTP_STATUS _http_urlencode_hash_recursive(HashTable *ht, phpstr *str, const char *arg_sep, size_t arg_sep_len, const char *prefix, size_t prefix_len TSRMLS_DC)
 {
 	HashKey key = initHashKey(0);
 	zval **data = NULL;
@@ -435,7 +435,7 @@
 		}
 		
 		if (Z_TYPE_PP(data) == IS_ARRAY || Z_TYPE_PP(data) == IS_OBJECT) {
-			STATUS status;
+			PECL_HTTP_STATUS status;
 			++ht->nApplyCount;
 			status = http_urlencode_hash_recursive(HASH_OF(*data), str, arg_sep, arg_sep_len, PHPSTR_VAL(&new_prefix), PHPSTR_LEN(&new_prefix));
 			--ht->nApplyCount;
diff -urN pecl_http-1.6.0,orig/php_http_api.h pecl_http-1.6.0/php_http_api.h
--- pecl_http-1.6.0,orig/php_http_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_api.h	2008-01-24 11:46:27.000000000 +0900
@@ -65,7 +65,7 @@
 typedef zend_object_value (*http_object_new_t)(zend_class_entry *ce, void *, void ** TSRMLS_DC);
 
 #define http_object_new(ov, cn, cl, co, ce, i, pp) _http_object_new((ov), (cn), (cl), (http_object_new_t) (co), (ce), (i), (void *) (pp) TSRMLS_CC)
-extern STATUS _http_object_new(zend_object_value *ov, const char *cname_str, uint cname_len, http_object_new_t create, zend_class_entry *parent_ce, void *intern_ptr, void **obj_ptr TSRMLS_DC);
+extern PECL_HTTP_STATUS _http_object_new(zend_object_value *ov, const char *cname_str, uint cname_len, http_object_new_t create, zend_class_entry *parent_ce, void *intern_ptr, void **obj_ptr TSRMLS_DC);
 #endif /* ZEND_ENGINE_2 */
 
 
@@ -132,11 +132,11 @@
 
 #define http_exit(s, h) http_exit_ex((s), (h), NULL, 1)
 #define http_exit_ex(s, h, b, e) _http_exit_ex((s), (h), (b), (e) TSRMLS_CC)
-extern STATUS _http_exit_ex(int status, char *header, char *body, zend_bool send_header TSRMLS_DC);
+extern PECL_HTTP_STATUS _http_exit_ex(int status, char *header, char *body, zend_bool send_header TSRMLS_DC);
 
 #define http_check_method(m) http_check_method_ex((m), HTTP_KNOWN_METHODS)
 #define http_check_method_ex(m, a) _http_check_method_ex((m), (a))
-extern STATUS _http_check_method_ex(const char *method, const char *methods);
+extern PECL_HTTP_STATUS _http_check_method_ex(const char *method, const char *methods);
 
 #define http_got_server_var(v) (NULL != http_get_server_var_ex((v), strlen(v), 1))
 #define http_get_server_var(v, c) http_get_server_var_ex((v), strlen(v), (c))
@@ -145,7 +145,7 @@
 
 #define http_get_request_body(b, l) _http_get_request_body_ex((b), (l), 1 TSRMLS_CC)
 #define http_get_request_body_ex(b, l, d) _http_get_request_body_ex((b), (l), (d) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_get_request_body_ex(char **body, size_t *length, zend_bool dup TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_get_request_body_ex(char **body, size_t *length, zend_bool dup TSRMLS_DC);
 
 #define http_get_request_body_stream() _http_get_request_body_stream(TSRMLS_C)
 PHP_HTTP_API php_stream *_http_get_request_body_stream(TSRMLS_D);
@@ -158,7 +158,7 @@
 
 #define http_parse_params(s, f, ht) _http_parse_params_ex((s), (f), _http_parse_params_default_callback, (ht) TSRMLS_CC)
 #define http_parse_params_ex(s, f, cb, a) _http_parse_params_ex((s), (f), (cb), (a) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_parse_params_ex(const char *params, int flags, http_parse_params_callback cb, void *cb_arg TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_parse_params_ex(const char *params, int flags, http_parse_params_callback cb, void *cb_arg TSRMLS_DC);
 
 
 #define http_sleep(s) _http_sleep(s)
diff -urN pecl_http-1.6.0,orig/php_http_cache_api.h pecl_http-1.6.0/php_http_cache_api.h
--- pecl_http-1.6.0,orig/php_http_cache_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_cache_api.h	2008-01-24 11:46:27.000000000 +0900
@@ -139,13 +139,13 @@
 PHP_HTTP_API zend_bool _http_match_etag_ex(const char *entry, const char *etag, zend_bool enforce_presence TSRMLS_DC);
 
 #define http_cache_last_modified(l, s, cc, ccl) _http_cache_last_modified((l), (s), (cc), (ccl) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_cache_last_modified(time_t last_modified, time_t send_modified, const char *cache_control, size_t cc_len TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_cache_last_modified(time_t last_modified, time_t send_modified, const char *cache_control, size_t cc_len TSRMLS_DC);
 
 #define http_cache_etag(e, el, cc, ccl) _http_cache_etag((e), (el), (cc), (ccl) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_cache_etag(const char *etag, size_t etag_len, const char *cache_control, size_t cc_len TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_cache_etag(const char *etag, size_t etag_len, const char *cache_control, size_t cc_len TSRMLS_DC);
 
 #define http_start_ob_etaghandler() _http_start_ob_etaghandler(TSRMLS_C)
-PHP_HTTP_API STATUS _http_start_ob_etaghandler(TSRMLS_D);
+PHP_HTTP_API PECL_HTTP_STATUS _http_start_ob_etaghandler(TSRMLS_D);
 #define http_interrupt_ob_etaghandler() _http_interrupt_ob_etaghandler(TSRMLS_C)
 PHP_HTTP_API zend_bool _http_interrupt_ob_etaghandler(TSRMLS_D);
 
diff -urN pecl_http-1.6.0,orig/php_http_encoding_api.h pecl_http-1.6.0/php_http_encoding_api.h
--- pecl_http-1.6.0,orig/php_http_encoding_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_encoding_api.h	2008-01-24 11:46:28.000000000 +0900
@@ -142,18 +142,18 @@
 } http_encoding_stream;
 
 #define http_encoding_deflate(f, d, dl, r, rl) _http_encoding_deflate((f), (d), (dl), (r), (rl) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_deflate(int flags, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate(int flags, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_inflate(d, dl, r, rl) _http_encoding_inflate((d), (dl), (r), (rl) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_inflate(const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate(const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 
 #define http_encoding_deflate_stream_init(s, f) _http_encoding_deflate_stream_init((s), (f) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
 PHP_HTTP_API http_encoding_stream *_http_encoding_deflate_stream_init(http_encoding_stream *s, int flags ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_deflate_stream_update(s, d, dl, e, el) _http_encoding_deflate_stream_update((s), (d), (dl), (e), (el) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_deflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_deflate_stream_flush(s, e, el) _http_encoding_deflate_stream_flush((s), (e), (el) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_deflate_stream_flush(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate_stream_flush(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_deflate_stream_finish(s, e, el) _http_encoding_deflate_stream_finish((s), (e), (el) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_deflate_stream_finish(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_deflate_stream_finish(http_encoding_stream *s, char **encoded, size_t *encoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_deflate_stream_dtor(s) _http_encoding_deflate_stream_dtor((s) TSRMLS_CC)
 PHP_HTTP_API void _http_encoding_deflate_stream_dtor(http_encoding_stream *s TSRMLS_DC);
 #define http_encoding_deflate_stream_free(s) _http_encoding_deflate_stream_free((s) TSRMLS_CC)
@@ -162,11 +162,11 @@
 #define http_encoding_inflate_stream_init(s, f) _http_encoding_inflate_stream_init((s), (f) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
 PHP_HTTP_API http_encoding_stream *_http_encoding_inflate_stream_init(http_encoding_stream *s, int flags ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_inflate_stream_update(s, d, dl, e, el) _http_encoding_inflate_stream_update((s), (d), (dl), (e), (el) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_inflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate_stream_update(http_encoding_stream *s, const char *data, size_t data_len, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_inflate_stream_flush(s, d, dl) _http_encoding_inflate_stream_flush((s), (d), (dl) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_inflate_stream_flush(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate_stream_flush(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_inflate_stream_finish(s, e, el) _http_encoding_inflate_stream_finish((s), (e), (el) ZEND_FILE_LINE_CC ZEND_FILE_LINE_EMPTY_CC TSRMLS_CC)
-PHP_HTTP_API STATUS _http_encoding_inflate_stream_finish(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_encoding_inflate_stream_finish(http_encoding_stream *s, char **decoded, size_t *decoded_len ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 #define http_encoding_inflate_stream_dtor(s) _http_encoding_inflate_stream_dtor((s) TSRMLS_CC)
 PHP_HTTP_API void _http_encoding_inflate_stream_dtor(http_encoding_stream *s TSRMLS_DC);
 #define http_encoding_inflate_stream_free(s) _http_encoding_inflate_stream_free((s) TSRMLS_CC)
diff -urN pecl_http-1.6.0,orig/php_http_headers_api.h pecl_http-1.6.0/php_http_headers_api.h
--- pecl_http-1.6.0,orig/php_http_headers_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_headers_api.h	2008-01-24 11:46:28.000000000 +0900
@@ -26,7 +26,7 @@
 #define http_parse_headers(h, a) _http_parse_headers_ex((h), Z_ARRVAL_P(a), 1, http_info_default_callback, NULL TSRMLS_CC)
 #define http_parse_headers_ex(h, ht, p) _http_parse_headers_ex((h), (ht), (p), http_info_default_callback, NULL TSRMLS_CC)
 #define http_parse_headers_cb(h, ht, p, f, d) _http_parse_headers_ex((h), (ht), (p), (f), (d) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_parse_headers_ex(const char *header, HashTable *headers, zend_bool prettify, http_info_callback callback_func, void **callback_data TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_parse_headers_ex(const char *header, HashTable *headers, zend_bool prettify, http_info_callback callback_func, void **callback_data TSRMLS_DC);
 
 typedef char *(*negotiate_func_t)(const char *test, double *quality, HashTable *supported TSRMLS_DC);
 
@@ -56,7 +56,7 @@
 PHP_HTTP_API void _http_get_request_headers(HashTable *headers TSRMLS_DC);
 
 #define http_get_response_headers(h) _http_get_response_headers((h) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_get_response_headers(HashTable *headers_ht TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_get_response_headers(HashTable *headers_ht TSRMLS_DC);
 
 #define http_match_request_header(h, v) http_match_request_header_ex((h), (v), 0)
 #define http_match_request_header_ex(h, v, c) _http_match_request_header_ex((h), (v), (c) TSRMLS_CC)
diff -urN pecl_http-1.6.0,orig/php_http_info_api.h pecl_http-1.6.0/php_http_info_api.h
--- pecl_http-1.6.0,orig/php_http_info_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_info_api.h	2008-01-24 11:46:29.000000000 +0900
@@ -64,7 +64,7 @@
 PHP_HTTP_API void _http_info_dtor(http_info *info);
 #define http_info_parse(p, i) _http_info_parse_ex((p), (i), 1 TSRMLS_CC)
 #define http_info_parse_ex(p, i, s) _http_info_parse_ex((p), (i), (s) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_info_parse_ex(const char *pre_header, http_info *info , zend_bool silent TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_info_parse_ex(const char *pre_header, http_info *info , zend_bool silent TSRMLS_DC);
 
 #endif
 
diff -urN pecl_http-1.6.0,orig/php_http_message_api.h pecl_http-1.6.0/php_http_message_api.h
--- pecl_http-1.6.0,orig/php_http_message_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_message_api.h	2008-01-24 11:46:29.000000000 +0900
@@ -107,7 +107,7 @@
 PHP_HTTP_API void _http_message_tostruct_recursive(http_message *msg, zval *strct TSRMLS_DC);
 
 #define http_message_send(m) _http_message_send((m) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_message_send(http_message *message TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_message_send(http_message *message TSRMLS_DC);
 
 #define http_message_dup(m) _http_message_dup((m) TSRMLS_CC)
 PHP_HTTP_API http_message *_http_message_dup(http_message *msg TSRMLS_DC);
diff -urN pecl_http-1.6.0,orig/php_http_persistent_handle_api.h pecl_http-1.6.0/php_http_persistent_handle_api.h
--- pecl_http-1.6.0,orig/php_http_persistent_handle_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_persistent_handle_api.h	2008-01-24 11:46:29.000000000 +0900
@@ -24,7 +24,7 @@
 
 #define http_persistent_handle_provide(n, c, d, cc) _http_persistent_handle_provide_ex((n), strlen(n), (c), (d), (cc))
 #define http_persistent_handle_provide_ex(n, l, c, d, cc) _http_persistent_handle_provide_ex((n), (l), (c), (d), (cc))
-PHP_HTTP_API STATUS _http_persistent_handle_provide_ex(const char *name_str, size_t name_len, http_persistent_handle_ctor ctor, http_persistent_handle_dtor dtor, http_persistent_handle_copy copy);
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_provide_ex(const char *name_str, size_t name_len, http_persistent_handle_ctor ctor, http_persistent_handle_dtor dtor, http_persistent_handle_copy copy);
 
 #define http_persistent_handle_cleanup(n, c) _http_persistent_handle_cleanup_ex((n), strlen(n), (c) TSRMLS_CC)
 #define http_persistent_handle_cleanup_ex(n, l,c ) _http_persistent_handle_cleanup_ex((n), (l), (c) TSRMLS_CC)
@@ -36,15 +36,15 @@
 
 #define http_persistent_handle_acquire(n, h) _http_persistent_handle_acquire_ex((n), strlen(n), (h) TSRMLS_CC)
 #define http_persistent_handle_acquire_ex(n, l, h) _http_persistent_handle_acquire_ex((n), (l), (h) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_persistent_handle_acquire_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_acquire_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC);
 
 #define http_persistent_handle_release(n, h) _http_persistent_handle_release_ex((n), strlen(n), (h) TSRMLS_CC)
 #define http_persistent_handle_release_ex(n, l, h) _http_persistent_handle_release_ex((n), (l), (h) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_persistent_handle_release_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_release_ex(const char *name_str, size_t name_len, void **handle TSRMLS_DC);
 
 #define http_persistent_handle_accrete(n, oh, nh) _http_persistent_handle_accrete_ex((n), strlen(n), (oh), (nh) TSRMLS_CC)
 #define http_persistent_handle_accrete_ex(n, l, oh, nh) _http_persistent_handle_accrete_ex((n), (l), (oh), (nh) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_persistent_handle_accrete_ex(const char *name_str, size_t name_len, void *old_handle, void **new_handle TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_persistent_handle_accrete_ex(const char *name_str, size_t name_len, void *old_handle, void **new_handle TSRMLS_DC);
 
 #endif /* HTTP_PERSISTENT_HANDLE_H */
 
diff -urN pecl_http-1.6.0,orig/php_http_request_api.h pecl_http-1.6.0/php_http_request_api.h
--- pecl_http-1.6.0,orig/php_http_request_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_request_api.h	2008-01-24 11:46:30.000000000 +0900
@@ -107,19 +107,19 @@
 PHP_HTTP_API void _http_request_reset(http_request *r);
 
 #define http_request_enable_cookies(r) _http_request_enable_cookies(r)
-PHP_HTTP_API STATUS _http_request_enable_cookies(http_request *request);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_enable_cookies(http_request *request);
 
 #define http_request_reset_cookies(r, s) _http_request_reset_cookies((r), (s))
-PHP_HTTP_API STATUS _http_request_reset_cookies(http_request *request, int session_only);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_reset_cookies(http_request *request, int session_only);
 
 #define http_request_flush_cookies(r) _http_request_flush_cookies(r)
-PHP_HTTP_API STATUS _http_request_flush_cookies(http_request *request);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_flush_cookies(http_request *request);
 
 #define http_request_defaults(r) _http_request_defaults(r)
 PHP_HTTP_API void _http_request_defaults(http_request *request);
 
 #define http_request_prepare(r, o) _http_request_prepare((r), (o))
-PHP_HTTP_API STATUS _http_request_prepare(http_request *request, HashTable *options);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_prepare(http_request *request, HashTable *options);
 
 #define http_request_exec(r) _http_request_exec((r))
 PHP_HTTP_API void _http_request_exec(http_request *request);
diff -urN pecl_http-1.6.0,orig/php_http_request_body_api.h pecl_http-1.6.0/php_http_request_body_api.h
--- pecl_http-1.6.0,orig/php_http_request_body_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_request_body_api.h	2008-01-24 11:46:30.000000000 +0900
@@ -40,7 +40,7 @@
 PHP_HTTP_API http_request_body *_http_request_body_fill(http_request_body *body, HashTable *fields, HashTable *files ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC TSRMLS_DC);
 
 #define http_request_body_encode(b, s, l) _http_request_body_encode((b), (s), (l) TSRMLS_CC)
-PHP_HTTP_API STATUS  _http_request_body_encode(http_request_body *body, char **buf, size_t *len TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS  _http_request_body_encode(http_request_body *body, char **buf, size_t *len TSRMLS_DC);
 
 #define http_request_body_dtor(b) _http_request_body_dtor((b) TSRMLS_CC)
 PHP_HTTP_API void _http_request_body_dtor(http_request_body *body TSRMLS_DC);
diff -urN pecl_http-1.6.0,orig/php_http_request_datashare_api.h pecl_http-1.6.0/php_http_request_datashare_api.h
--- pecl_http-1.6.0,orig/php_http_request_datashare_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_request_datashare_api.h	2008-01-24 11:46:30.000000000 +0900
@@ -55,10 +55,10 @@
 PHP_HTTP_API http_request_datashare *_http_request_datashare_init_ex(http_request_datashare *share, zend_bool persistent TSRMLS_DC);
 
 #define http_request_datashare_attach(s, r) _http_request_datashare_attach((s), (r) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_request_datashare_attach(http_request_datashare *share, zval *request TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_datashare_attach(http_request_datashare *share, zval *request TSRMLS_DC);
 
 #define http_request_datashare_detach(s, r) _http_request_datashare_detach((s), (r) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_request_datashare_detach(http_request_datashare *share, zval *request TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_datashare_detach(http_request_datashare *share, zval *request TSRMLS_DC);
 
 #define http_request_datashare_detach_all(s) _http_request_datashare_detach_all((s) TSRMLS_CC)
 PHP_HTTP_API void _http_request_datashare_detach_all(http_request_datashare *share TSRMLS_DC);
@@ -70,7 +70,7 @@
 PHP_HTTP_API void _http_request_datashare_free(http_request_datashare **share TSRMLS_DC);
 
 #define http_request_datashare_set(s, o, l, e) _http_request_datashare_set((s), (o), (l), (e) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_request_datashare_set(http_request_datashare *share, const char *option, size_t option_len, zend_bool enable TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_datashare_set(http_request_datashare *share, const char *option, size_t option_len, zend_bool enable TSRMLS_DC);
 
 
 #endif
diff -urN pecl_http-1.6.0,orig/php_http_request_method_api.h pecl_http-1.6.0/php_http_request_method_api.h
--- pecl_http-1.6.0,orig/php_http_request_method_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_request_method_api.h	2008-01-24 11:46:31.000000000 +0900
@@ -70,7 +70,7 @@
 PHP_HTTP_API int _http_request_method_register(const char *method, int method_name_len TSRMLS_DC);
 
 #define http_request_method_unregister(mn) _http_request_method_unregister((mn) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_request_method_unregister(int method TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_method_unregister(int method TSRMLS_DC);
 
 #endif
 
diff -urN pecl_http-1.6.0,orig/php_http_request_object.h pecl_http-1.6.0/php_http_request_object.h
--- pecl_http-1.6.0,orig/php_http_request_object.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_request_object.h	2008-01-24 11:46:31.000000000 +0900
@@ -43,9 +43,9 @@
 extern void _http_request_object_free(zend_object *object TSRMLS_DC);
 
 #define http_request_object_requesthandler(req, this) _http_request_object_requesthandler((req), (this) TSRMLS_CC)
-extern STATUS _http_request_object_requesthandler(http_request_object *obj, zval *this_ptr TSRMLS_DC);
+extern PECL_HTTP_STATUS _http_request_object_requesthandler(http_request_object *obj, zval *this_ptr TSRMLS_DC);
 #define http_request_object_responsehandler(req, this) _http_request_object_responsehandler((req), (this) TSRMLS_CC)
-extern STATUS _http_request_object_responsehandler(http_request_object *obj, zval *this_ptr TSRMLS_DC);
+extern PECL_HTTP_STATUS _http_request_object_responsehandler(http_request_object *obj, zval *this_ptr TSRMLS_DC);
 
 PHP_METHOD(HttpRequest, __construct);
 PHP_METHOD(HttpRequest, setOptions);
diff -urN pecl_http-1.6.0,orig/php_http_request_pool_api.h pecl_http-1.6.0/php_http_request_pool_api.h
--- pecl_http-1.6.0,orig/php_http_request_pool_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_request_pool_api.h	2008-01-24 11:46:31.000000000 +0900
@@ -53,10 +53,10 @@
 PHP_HTTP_API http_request_pool *_http_request_pool_init(http_request_pool *pool TSRMLS_DC);
 
 #define http_request_pool_attach(p, r) _http_request_pool_attach((p), (r))
-PHP_HTTP_API STATUS _http_request_pool_attach(http_request_pool *pool, zval *request);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_attach(http_request_pool *pool, zval *request);
 
 #define http_request_pool_detach(p, r) _http_request_pool_detach((p), (r))
-PHP_HTTP_API STATUS _http_request_pool_detach(http_request_pool *pool, zval *request);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_detach(http_request_pool *pool, zval *request);
 
 #define http_request_pool_apply(p, f) _http_request_pool_apply((p), (f))
 PHP_HTTP_API void _http_request_pool_apply(http_request_pool *pool, http_request_pool_apply_func cb);
@@ -68,10 +68,10 @@
 PHP_HTTP_API void _http_request_pool_detach_all(http_request_pool *pool);
 
 #define http_request_pool_send(p) _http_request_pool_send((p))
-PHP_HTTP_API STATUS _http_request_pool_send(http_request_pool *pool);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_send(http_request_pool *pool);
 
 #define http_request_pool_select _http_request_pool_select
-PHP_HTTP_API STATUS _http_request_pool_select(http_request_pool *pool);
+PHP_HTTP_API PECL_HTTP_STATUS _http_request_pool_select(http_request_pool *pool);
 
 #define http_request_pool_perform(p) _http_request_pool_perform((p))
 PHP_HTTP_API int _http_request_pool_perform(http_request_pool *pool);
diff -urN pecl_http-1.6.0,orig/php_http_send_api.h pecl_http-1.6.0/php_http_send_api.h
--- pecl_http-1.6.0,orig/php_http_send_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_send_api.h	2008-01-24 11:46:32.000000000 +0900
@@ -32,12 +32,12 @@
 #define http_send_status(s) sapi_header_op(SAPI_HEADER_SET_STATUS, (void *) (long) (s) TSRMLS_CC)
 #define http_send_header(n, v, r) _http_send_header_ex((n), strlen(n), (v), strlen(v), (r), NULL TSRMLS_CC)
 #define http_send_header_ex(n, nl, v, vl, r, s) _http_send_header_ex((n), (nl), (v), (vl), (r), (s) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_header_ex(const char *name, size_t name_len, const char *value, size_t value_len, zend_bool replace, char **sent_header TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_header_ex(const char *name, size_t name_len, const char *value, size_t value_len, zend_bool replace, char **sent_header TSRMLS_DC);
 #define http_send_header_string(h) _http_send_status_header_ex(0, (h), strlen(h), 1 TSRMLS_CC)
 #define http_send_header_string_ex(h, l, r) _http_send_status_header_ex(0, (h), (l), (r) TSRMLS_CC)
 #define http_send_status_header(s, h) _http_send_status_header_ex((s), (h), (h)?strlen(h):0, 1 TSRMLS_CC)
 #define http_send_status_header_ex(s, h, l, r) _http_send_status_header_ex((s), (h), (l), (r) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_status_header_ex(int status, const char *header, size_t header_len, zend_bool replace TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_status_header_ex(int status, const char *header, size_t header_len, zend_bool replace TSRMLS_DC);
 
 #define http_send_header_zval(n, z, r) http_send_header_zval_ex((n), strlen(n), (z), (r))
 #define http_send_header_zval_ex(n, l, z, r) _http_send_header_zval_ex((n), (l), (z), (r) TSRMLS_CC)
@@ -49,31 +49,31 @@
 
 #define http_send_last_modified(t) _http_send_last_modified_ex((t), NULL TSRMLS_CC)
 #define http_send_last_modified_ex(t, s) _http_send_last_modified_ex((t), (s) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_last_modified_ex(time_t t, char **sent_header TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_last_modified_ex(time_t t, char **sent_header TSRMLS_DC);
 
 #define http_send_etag(e, l) _http_send_etag_ex((e), (l), NULL TSRMLS_CC)
 #define http_send_etag_ex(e, l, s) _http_send_etag_ex((e), (l), (s) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_etag_ex(const char *etag, size_t etag_len, char **sent_header TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_etag_ex(const char *etag, size_t etag_len, char **sent_header TSRMLS_DC);
 
 #define http_send_cache_control(cc, cl) http_send_header_ex("Cache-Control", lenof("Cache-Control"), (cc), (cl), 1, NULL)
 
 #define http_send_content_type(c, l) _http_send_content_type((c), (l) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_content_type(const char *content_type, size_t ct_len TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_content_type(const char *content_type, size_t ct_len TSRMLS_DC);
 
 #define http_send_content_disposition(f, l, i) _http_send_content_disposition((f), (l), (i) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_content_disposition(const char *filename, size_t f_len, zend_bool send_inline TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_content_disposition(const char *filename, size_t f_len, zend_bool send_inline TSRMLS_DC);
 
 #define http_send_data(d, l) http_send((d), (l), SEND_DATA)
 #define http_send_data_ex(d, l, nc) http_send_ex((d), (l), SEND_DATA, (nc))
 #define http_send(d, s, m) _http_send_ex((d), (s), (m), 0 TSRMLS_CC)
 #define http_send_ex(d, s, m, nc) _http_send_ex((d), (s), (m), (nc) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_ex(const void *data, size_t data_size, http_send_mode mode, zend_bool no_cache TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_ex(const void *data, size_t data_size, http_send_mode mode, zend_bool no_cache TSRMLS_DC);
 
 #define http_send_file(f) http_send_stream_ex(php_stream_open_wrapper_ex(f, "rb", REPORT_ERRORS|ENFORCE_SAFE_MODE, NULL, HTTP_DEFAULT_STREAM_CONTEXT), 1, 0)
 #define http_send_file_ex(f, nc) http_send_stream_ex(php_stream_open_wrapper_ex(f, "rb", REPORT_ERRORS|ENFORCE_SAFE_MODE, NULL, HTTP_DEFAULT_STREAM_CONTEXT), 1, (nc))
 #define http_send_stream(s) http_send_stream_ex((s), 0, 0)
 #define http_send_stream_ex(s, c, nc) _http_send_stream_ex((s), (c), (nc) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_send_stream_ex(php_stream *s, zend_bool close_stream, zend_bool no_cache TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_send_stream_ex(php_stream *s, zend_bool close_stream, zend_bool no_cache TSRMLS_DC);
 
 #define http_guess_content_type(mf, mm, d, l, m) _http_guess_content_type((mf), (mm), (d), (l), (m) TSRMLS_CC)
 PHP_HTTP_API char *_http_guess_content_type(const char *magic_file, long magic_mode, void *data_ptr, size_t data_len, http_send_mode mode TSRMLS_DC);
diff -urN pecl_http-1.6.0,orig/php_http_std_defs.h pecl_http-1.6.0/php_http_std_defs.h
--- pecl_http-1.6.0,orig/php_http_std_defs.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_std_defs.h	2008-01-24 11:46:32.000000000 +0900
@@ -28,7 +28,7 @@
 #endif
 
 /* make functions that return SUCCESS|FAILURE more obvious */
-typedef int STATUS;
+typedef int PECL_HTTP_STATUS;
 
 /* lenof() */
 #define lenof(S) (sizeof(S) - 1)
diff -urN pecl_http-1.6.0,orig/php_http_url_api.h pecl_http-1.6.0/php_http_url_api.h
--- pecl_http-1.6.0,orig/php_http_url_api.h	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/php_http_url_api.h	2008-01-24 11:46:32.000000000 +0900
@@ -47,10 +47,10 @@
 
 #define http_urlencode_hash(h, q) _http_urlencode_hash_ex((h), 1, NULL, 0, (q), NULL TSRMLS_CC)
 #define http_urlencode_hash_ex(h, o, p, pl, q, ql) _http_urlencode_hash_ex((h), (o), (p), (pl), (q), (ql) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_urlencode_hash_ex(HashTable *hash, zend_bool override_argsep, char *pre_encoded_data, size_t pre_encoded_len, char **encoded_data, size_t *encoded_len TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_urlencode_hash_ex(HashTable *hash, zend_bool override_argsep, char *pre_encoded_data, size_t pre_encoded_len, char **encoded_data, size_t *encoded_len TSRMLS_DC);
 
 #define http_urlencode_hash_recursive(ht, s, as, al, pr, pl) _http_urlencode_hash_recursive((ht), (s), (as), (al), (pr), (pl) TSRMLS_CC)
-PHP_HTTP_API STATUS _http_urlencode_hash_recursive(HashTable *ht, phpstr *str, const char *arg_sep, size_t arg_sep_len, const char *prefix, size_t prefix_len TSRMLS_DC);
+PHP_HTTP_API PECL_HTTP_STATUS _http_urlencode_hash_recursive(HashTable *ht, phpstr *str, const char *arg_sep, size_t arg_sep_len, const char *prefix, size_t prefix_len TSRMLS_DC);
 
 #define http_url_from_struct(u, ht) _http_url_from_struct((u), (ht) TSRMLS_CC)
 static inline php_url *_http_url_from_struct(php_url *url, HashTable *ht TSRMLS_DC)

なんとなく、odbc接続の方が良い気がしてきた。要検討。
ただ、SQL Serverなんて使いたくないよぅ。文字コード周りで絶対に一悶着ありそうだし、.NETかJavaでやった方が絶対に幸せになれると思う。色んな意味で。
それにしても、せっかく逃れられたと思ったのにぃ。。。まさか再燃するなんて。
相手が相手だけにヤバすぎる。久々の窮地かもしれない。。。っていうか、過去最大カモ。
diff -urN pecl_http-1.6.0,orig/http_api.c pecl_http-1.6.0/http_api.c
--- pecl_http-1.6.0,orig/http_api.c	2007-11-26 23:54:40.000000000 +0900
+++ pecl_http-1.6.0/http_api.c	2008-01-24 11:46:20.000000000 +0900
@@ -186,8 +186,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_object_new(zend_object_value *, const char *, uint, http_object_new_t, zend_class_entry *, void *, void **) */
-STATUS _http_object_new(zend_object_value *ov, const char *cname_str, uint cname_len, http_object_new_t create, zend_class_entry *parent_ce, void *intern_ptr, void **obj_ptr TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_object_new(zend_object_value *, const char *, uint, http_object_new_t, zend_class_entry *, void *, void **) */
+PECL_HTTP_STATUS _http_object_new(zend_object_value *ov, const char *cname_str, uint cname_len, http_object_new_t create, zend_class_entry *parent_ce, void *intern_ptr, void **obj_ptr TSRMLS_DC)
 {
 	zend_class_entry *ce = parent_ce;
 	
@@ -239,8 +239,8 @@
 	*handled_output_len = 0;
 }
 
-/* {{{ STATUS http_exit(int, char*, char*) */
-STATUS _http_exit_ex(int status, char *header, char *body, zend_bool send_header TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_exit(int, char*, char*) */
+PECL_HTTP_STATUS _http_exit_ex(int status, char *header, char *body, zend_bool send_header TSRMLS_DC)
 {
 	if (	(send_header && (SUCCESS != http_send_status_header(status, header))) ||
 			(status && (SUCCESS != http_send_status(status)))) {
@@ -282,8 +282,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_check_method(char *) */
-STATUS _http_check_method_ex(const char *method, const char *methods)
+/* {{{ PECL_HTTP_STATUS http_check_method(char *) */
+PECL_HTTP_STATUS _http_check_method_ex(const char *method, const char *methods)
 {
 	const char *found;
 
@@ -332,8 +332,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_get_request_body(char **, size_t *) */
-PHP_HTTP_API STATUS _http_get_request_body_ex(char **body, size_t *length, zend_bool dup TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_get_request_body(char **, size_t *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_get_request_body_ex(char **body, size_t *length, zend_bool dup TSRMLS_DC)
 {
 	*length = 0;
 	*body = NULL;
@@ -438,8 +438,8 @@
 }
 /* }}} */
 
-/* {{{ STATUS http_parse_params(const char *, HashTable *) */
-PHP_HTTP_API STATUS _http_parse_params_ex(const char *param, int flags, http_parse_params_callback cb, void *cb_arg TSRMLS_DC)
+/* {{{ PECL_HTTP_STATUS http_parse_params(const char *, HashTable *) */
+PHP_HTTP_API PECL_HTTP_STATUS _http_parse_params_ex(const char *param, int flags, http_parse_params_callback cb, void *cb_arg TSRMLS_DC)
 {
 #define ST_QUOTE	1
 #define ST_VALUE	2